@@ -1,6 +1,6 @@
 package MooseX::Storage::Engine;
 # ABSTRACT: The meta-engine to handle collapsing and expanding objects
-$MooseX::Storage::Engine::VERSION = '0.48';
+our $VERSION = '0.49';
 use Moose;
 use Scalar::Util qw(refaddr blessed);
 use Carp 'confess';
@@ -211,7 +211,8 @@ my %OBJECT_HANDLERS = (
 );
 
 
-my %TYPES = (
+my %TYPES;
+%TYPES = (
     # NOTE:
     # we need to make sure that we properly numify the numbers
     # before and after them being futzed with, because some of
@@ -223,23 +224,18 @@ my %TYPES = (
     'Value'    => { expand => sub { shift }, collapse => sub { shift } },
     'Bool'     => { expand => sub { shift }, collapse => sub { shift } },
     # These are the trickier ones, (see notes)
-    # NOTE:
-    # Because we are nice guys, we will check
-    # your ArrayRef and/or HashRef one level
-    # down and inflate any objects we find.
-    # But this is where it ends, it is too
-    # expensive to try and do this any more
-    # recursively, when it is probably not
-    # nessecary in most of the use cases.
-    # However, if you need more then this, subtype
-    # and add a custom handler.
     'ArrayRef' => {
         expand => sub {
             my ( $array, @args ) = @_;
             foreach my $i (0 .. $#{$array}) {
-                next unless ref($array->[$i]) eq 'HASH'
-                         && exists $array->[$i]->{$CLASS_MARKER};
-                $array->[$i] = $OBJECT_HANDLERS{expand}->($array->[$i], @args);
+                if (ref($array->[$i]) eq 'HASH') {
+                    $array->[$i] = exists($array->[$i]{$CLASS_MARKER})
+                        ? $OBJECT_HANDLERS{expand}->($array->[$i], @args)
+                        : $TYPES{HashRef}{expand}->($array->[$i], @args);
+                }
+                elsif (ref($array->[$i]) eq 'ARRAY') {
+                    $array->[$i] = $TYPES{ArrayRef}{expand}->($array->[$i], @args);
+                }
             }
             $array;
         },
@@ -252,6 +248,8 @@ my %TYPES = (
             [ map {
                 blessed($_)
                     ? $OBJECT_HANDLERS{collapse}->($_, @args)
+                    : $TYPES{ref($_)}
+                    ? $TYPES{ref($_)}->{collapse}->($_, @args)
                     : $_
             } @$array ]
         }
@@ -260,9 +258,14 @@ my %TYPES = (
         expand   => sub {
             my ( $hash, @args ) = @_;
             foreach my $k (keys %$hash) {
-                next unless ref($hash->{$k}) eq 'HASH'
-                         && exists $hash->{$k}->{$CLASS_MARKER};
-                $hash->{$k} = $OBJECT_HANDLERS{expand}->($hash->{$k}, @args);
+                if (ref($hash->{$k}) eq 'HASH' ) {
+                    $hash->{$k} = exists($hash->{$k}->{$CLASS_MARKER})
+                        ? $OBJECT_HANDLERS{expand}->($hash->{$k}, @args)
+                        : $TYPES{HashRef}{expand}->($hash->{$k}, @args);
+                }
+                elsif (ref($hash->{$k}) eq 'ARRAY') {
+                    $hash->{$k} = $TYPES{ArrayRef}{expand}->($hash->{$k}, @args);
+                }
             }
             $hash;
         },
@@ -275,6 +278,8 @@ my %TYPES = (
             +{ map {
                 blessed($hash->{$_})
                     ? ($_ => $OBJECT_HANDLERS{collapse}->($hash->{$_}, @args))
+                    : $TYPES{ref($hash->{$_})}
+                    ? ($_ => $TYPES{ref($hash->{$_})}{collapse}->($hash->{$_}, @args))
                     : ($_ => $hash->{$_})
             } keys %$hash }
         }
@@ -290,6 +295,13 @@ my %TYPES = (
     #}
 );
 
+%TYPES = (
+    %TYPES,
+    'HASH'  => $TYPES{HashRef},
+    'ARRAY' => $TYPES{ArrayRef},
+);
+
+
 sub add_custom_type_handler {
     my ($self, $type_name, %handlers) = @_;
     (exists $handlers{expand} && exists $handlers{collapse})
@@ -382,7 +394,7 @@ MooseX::Storage::Engine - The meta-engine to handle collapsing and expanding obj
 
 =head1 VERSION
 
-version 0.48
+version 0.49
 
 =head1 DESCRIPTION
 
@@ -393,7 +405,7 @@ assumes a C<DateTime> type has been registered.
 
     MooseX::Storage::Engine->add_custom_type_handler(
         'DateTime' => (
-            expand   => sub { DateTime->new(shift) },
+            expand   => sub { DateTime::Format::ISO8601->new->parser_datetime(shift) },
             collapse => sub { (shift)->iso8601 },
         )
     );
